/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id$
 *
 */

package org.ow2.sirocco.vmm.placementmanager.api;

import java.util.List;

import org.ow2.sirocco.vmm.api.ServerPoolMXBean;

/**
 * Manages the placement of virtual machines on a server pool in compliance with
 * affinity and anti-affinity rules
 */
public interface VMPlacementSolver {
    /**
     * Solves the initial placement of a virtual machine to be created on one
     * host of a server pool
     * 
     * @param serverPool the server pool where the VM must be be created
     * @param vmSpec the configuration settings of the VM to be created along
     *        with affinity and anti-affinity rules with existing VMs or hosts
     * @param placementRules the placement rules of the virtual machines already
     *        present on the server pool
     * @return the reconfiguration plan required to create the VM. This list of
     *         cluster actions must contain a VmCreationAction for the new VM
     *         and possibly VM migration actions required to accommodate the new
     *         VM
     * @throws UnsolvableConstraints raised if no placement solution can be
     *         found
     */
    List<ClusterAction> placeVirtualMachine(ServerPoolMXBean serverPool, VirtualMachineConfigSpecWithConstraints vmSpec,
        List<PlacementRule> placementRules) throws UnsolvableConstraints;

    /**
     * Solves the the placement of the virtual machines currently running on a
     * server pool
     * 
     * @param serverPool the server pool whose virtual machines' placement must
     *        be updated
     * @param placementRules the placement rules to enforce
     * @return a reconfiguration plan consisting of an ordered list of VM
     *         migration actions
     * @throws UnsolvableConstraints raised if no placement solution can be
     *         found
     */
    List<ClusterAction> solve(ServerPoolMXBean serverPool, List<PlacementRule> placementRules) throws UnsolvableConstraints;

}
