/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id$
 *
 */

package org.ow2.sirocco.vmm.placementmanager.api;

import java.util.List;

import org.ow2.sirocco.vmm.api.HostMXBean;
import org.ow2.sirocco.vmm.api.VirtualMachineConfigSpec;
import org.ow2.sirocco.vmm.api.VirtualMachineMXBean;

/**
 * VM Configuration settings with placement constraints
 */
@SuppressWarnings("serial")
public class VirtualMachineConfigSpecWithConstraints extends VirtualMachineConfigSpec {
    private List<VirtualMachineMXBean> affinityVirtualMachineGroup;

    private List<VirtualMachineMXBean> antiAffinityVirtualMachineGroup;

    private List<HostMXBean> affinityHostGroup;

    private List<HostMXBean> antiAffinityHostGroup;

    public VirtualMachineConfigSpecWithConstraints() {

    }

    public VirtualMachineConfigSpecWithConstraints(final VirtualMachineConfigSpec spec) {
        super(spec);
    }

    /**
     * the VM to be created must be colocated with this group of VMs
     * 
     * @return
     */
    public List<VirtualMachineMXBean> getAffinityVirtualMachineGroup() {
        return this.affinityVirtualMachineGroup;
    }

    public void setAffinityVirtualMachineGroup(final List<VirtualMachineMXBean> affinityVirtualMachineGroup) {
        this.affinityVirtualMachineGroup = affinityVirtualMachineGroup;
    }

    /**
     * the VM to be created must not be colocated with this group of VMs
     * 
     * @return
     */
    public List<VirtualMachineMXBean> getAntiAffinityVirtualMachineGroup() {
        return this.antiAffinityVirtualMachineGroup;
    }

    public void setAntiAffinityVirtualMachineGroup(final List<VirtualMachineMXBean> antiAffinityVirtualMachineGroup) {
        this.antiAffinityVirtualMachineGroup = antiAffinityVirtualMachineGroup;
    }

    /**
     * the VM to be created must be placed on this group of hosts
     * 
     * @return
     */
    public List<HostMXBean> getAffinityHostGroup() {
        return this.affinityHostGroup;
    }

    public void setAffinityHostGroup(final List<HostMXBean> affinityHostGroup) {
        this.affinityHostGroup = affinityHostGroup;
    }

    /**
     * the VM to be created must not be placed on this group of hosts
     * 
     * @return
     */
    public List<HostMXBean> getAntiAffinityHostGroup() {
        return this.antiAffinityHostGroup;
    }

    public void setAntiAffinityHostGroup(final List<HostMXBean> antiAffinityHostGroup) {
        this.antiAffinityHostGroup = antiAffinityHostGroup;
    }

    @Override
    public String toString() {
        return "VirtualMachineConfigSpecWithConstraints [ vmAffinity=" + this.affinityVirtualMachineGroup + ", vmAntiAffinity="
            + this.antiAffinityVirtualMachineGroup + ",hostAffinity=" + this.affinityHostGroup + ",hostAntiAffinity="
            + this.antiAffinityHostGroup + "]";
    }

}
